import request from '@/utils/request'

//列表
export function studyFormFill_list(query) {
  return request({
    url: '/system/business/studyFormFill/list',
    method: 'get',
    params: query
  })
}
//稽查轨迹
export function studyFormFill_jcgj(query) {
  return request({
    url: '/system/business/studyFormFill/jcgjList',
    method: 'get',
    params: query
  })
}
//导出
export function studyFormFill_exportDetail(query) {
  return request({
    url: '/system/business/studyFormFill/exportDetail',
    method: 'get',
    params: query
  })
}

//签名信息
export function studyFormFill_qmxx(query) {
  return request({
    url: '/system/business/studyFormFill/qmxxList',
    method: 'get',
    params: query
  })
}

//详情
export function studyFormFill_info(query) {
  return request({
    url: '/system/business/studyFormFill/info',
    method: 'get',
    params: query
  })
}

//加签
export function studyFormFill_jq(data) {
  return request({
    url: '/system/business/studyFormFill/jq',
    method: 'post',
    data: data
  })
}

//废止
export function studyFormFill_fz(data) {
  return request({
    url: '/system/business/studyFormFill/fz',
    method: 'post',
    data: data
  })
}

//确认废止
export function studyFormFill_qrfz(data) {
  return request({
    url: '/system/business/studyFormFill/qrfz',
    method: 'post',
    data: data
  })
}

//更换归属人
export function studyFormFill_ghgsr(data) {
  return request({
    url: '/system/business/studyFormFill/ghgsr',
    method: 'post',
    data: data
  })
}

//保存
export function studyFormFill_bc(data) {
  return request({
    url: '/system/business/studyFormFill/bc',
    method: 'post',
    data: data
  })
}

//仅保存
export function studyFormFill_bcOnly(data) {
  return request({
    url: '/system/business/studyFormFill/bcOnly',
    method: 'post',
    data: data
  })
}
//提交
export function studyFormFill_tj(data) {
  return request({
    url: '/system/business/studyFormFill/tj',
    method: 'post',
    data: data
  })
}

//观察
export function studyFormFill_gc(data) {
  return request({
    url: '/system/business/studyFormFill/gc',
    method: 'post',
    data: data
  })
}

//复核通过
export function studyFormFill_fhtg(data) {
  return request({
    url: '/system/business/studyFormFill/fhtg',
    method: 'post',
    data: data
  })
}

//复核拒绝
export function studyFormFill_fhjj(data) {
  return request({
    url: '/system/business/studyFormFill/fhjj',
    method: 'post',
    data: data
  })
}

//通过
export function studyFormFill_tg(data) {
  return request({
    url: '/system/business/studyFormFill/tg',
    method: 'post',
    data: data
  })
}

//审阅
export function studyFormFill_sy(data) {
  return request({
    url: '/system/business/studyFormFill/sy',
    method: 'post',
    data: data
  })
}


//保存字段勾选记录
export function studyFormFill_updateZdgxjl(data) {
  return request({
    url: '/system/business/studyFormFill/updateZdgxjl',
    method: 'post',
    data: data
  })
}

//保存复核意见
export function studyFormFill_updateFhyjjl(data) {
  return request({
    url: '/system/business/studyFormFill/updateFhyjjl',
    method: 'post',
    data: data
  })
}

//保存表单内容
export function studyFormFill_updateBdnr(data) {
  return request({
    url: '/system/business/studyFormFill/updateBdnr',
    method: 'post',
    data: data
  })
}